@@ -4,10 +4,7 @@ import datetime
 import dbstream
 import pyodbc
 import os
-
 import re
-import requests
-
 from pyzure.core.Column import create_columns, change_column_type
 from pyzure.core.Table import create_table
 from pyzure.core.tools.print_colors import C
@@ -178,7 +175,8 @@ class AzureDBStream(dbstream.DBStream):
             if "invalid object name" in str(e).lower():
                 create_table(
                     self,
-                    data_copy
+                    data_copy,
+                    other_table_to_update
                 )
             elif "invalid column name" in str(e).lower():
                 create_columns(self, data_copy, other_table_to_update)
@@ -196,10 +194,15 @@ class AzureDBStream(dbstream.DBStream):
                                    other_table_to_update=other_table_to_update, sub_commit=sub_commit)
 
     def get_max(self, schema, table, field, filter_clause=""):
-        r = self.execute_query("SELECT max(%s) as max FROM %s.%s %s" % (field, schema, table, filter_clause))
-        if r is None:
-            return r
-        return r[0]["max"]
+        try:
+            r = self.execute_query("SELECT max(%s) as max FROM %s.%s %s" % (field, schema, table, filter_clause))
+            return r[0]["max"]
+        except IndexError:
+            return None
+        except Exception as e:
+            if "object" in str(e):
+                return None
+            raise e
 
     def clean(self, selecting_id, schema_prefix, table):
         print('trying to clean table %s.%s using %s' % (schema_prefix, table, selecting_id))
